import datetime
import re

import requests


def inject_year(text):
    pattern = re.compile(r'\[yyyy\]|<year>')
    return pattern.sub(str(datetime.date.today().year), text)


def resolve(expression):
    """
    Resolve an SPDX license expression into a license text.

    >>> resolve('MIT')
    'MIT License...'
    """
    url = f"https://raw.githubusercontent.com/spdx/license-list-data/main/text/{expression}.txt"
    return inject_year(requests.get(url).text)



import functools
import pathlib

from . import resolve


def _finalize_license_files(dist):
    """
    Resolve the license expression into a license file.
    """
    license = pathlib.Path('LICENSE')
    license.write_text(resolve(dist.metadata.license_expression))
    dist.metadata.license_files = [str(license)]


def inject(dist):
    """
    Patch the dist to resolve the license expression.

    This hook is called before `dist.parse_config_files` has been called, so
    the license expression has not been loaded yet, so patch _finalize_license_files
    to write out the license after expressions are loaded.
    """
    dist._finalize_license_files = functools.partial(_finalize_license_files, dist)
